FauxFactory is written and maintained by Og Maciel and various
contributors.

Development Lead
````````````````

-  Og Maciel `@omaciel https://github.com/omaciel/`_

Contributors
````````````

- Corey Welton `@cswiii <https://github.com/cswiii/>`_
- Elyézer Rezende `@elyezer <https://github.com/elyezer/>`_
- Jefferson Fausto Vaz `@faustovaz <https://github.com/faustovaz/>`_
